@@ -1,9 +1,10 @@
 package Siebel::Srvrmgr;
-$Siebel::Srvrmgr::VERSION = '0.23';
+
 use warnings;
 use strict;
 use Log::Log4perl 1.41;
 use Carp;
+our $VERSION = '0.24'; #VERSION
 
 =pod
 
@@ -139,6 +140,11 @@ L<Siebel::Srvrmgr::ListParser>
 
 The project web page at L<https://github.com/glasswalk3r/siebel-monitoring-tools/> contains more information about project features and state.
 
+=item *
+
+PPM package: if you are a Active Perl user, you might be happy to know that there are PPM packages created automatically from this distribution
+at L<https://code.activestate.com/ppm/Siebel-Srvrmgr/>.
+
 =back
 
 =head1 AUTHOR
