@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon;
-$Siebel::Srvrmgr::Daemon::VERSION = '0.23';
+
 =pod
 
 =head1 NAME
@@ -45,6 +45,7 @@ use Config;
 use Carp;
 use File::Spec;
 use Data::Dumper;
+our $VERSION = '0.24'; # VERSION
 
 my $SIG_INT   = 0;
 my $SIG_PIPE  = 0;
@@ -652,7 +653,7 @@ sub shift_command {
     else {
 
         $self->set_commands( [] );         # must trigger the attribute
-        return undef;
+        return;
 
     }
 
@@ -725,12 +726,11 @@ sub normalize_eol {
 
     confess 'data parameter must be an array or scalar reference'
       unless ( ( $ref_type eq 'ARRAY' ) or ( $ref_type eq 'SCALAR' ) );
-
-    my $c_regex = qr/\015?\012/;
+    my $c_regex = qr/\o{15}?\o{12}/;
 
     if ( $ref_type eq 'ARRAY' ) {
 
-        local $/ = \012;
+        local $/ = "\o{12}";
 
         foreach ( @{$data_ref} ) {
 
