@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::Action;
-$Siebel::Srvrmgr::Daemon::Action::VERSION = '0.23';
+
 =pod
 
 =head1 NAME
@@ -49,9 +49,10 @@ infinite loop.
 
 =cut
 
-use Moose;
+use Moose 2.0401;
 use namespace::autoclean 0.13;
 use Carp;
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
