@@ -1,7 +1,10 @@
 package Siebel::Srvrmgr::Daemon::Action::Check::Server;
-$Siebel::Srvrmgr::Daemon::Action::Check::Server::VERSION = '0.23';
-use Moose::Role;
+
+use warnings;
+use strict;
+use Moose::Role 2.0401;
 use Siebel::Srvrmgr::Types;
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
