@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::Action::ListParams;
-$Siebel::Srvrmgr::Daemon::Action::ListParams::VERSION = '0.23';
+
 =pod
 
 =head1 NAME
@@ -20,6 +20,7 @@ use namespace::autoclean 0.13;
 
 extends 'Siebel::Srvrmgr::Daemon::Action';
 with 'Siebel::Srvrmgr::Daemon::Action::Serializable';
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
@@ -44,8 +45,7 @@ override 'do_parsed' => sub {
 
     if ( blessed($obj) eq $self->get_exp_output() ) {
 
-        $obj->store( $self->get_dump_file() );
-
+        $self->store($obj);
         return 1;
 
     }
