@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::Action::ListSessions;
-$Siebel::Srvrmgr::Daemon::Action::ListSessions::VERSION = '0.23';
+
 =pod
 
 =head1 NAME
@@ -16,12 +16,13 @@ This is a subclass of L<Siebel::Srvrmgr::Daemon::Action> that will recover sessi
 
 =cut
 
-use Moose;
-use namespace::autoclean;
+use Moose 2.0401;
+use namespace::autoclean 0.13;
 use Siebel::Srvrmgr;
 use Siebel::Srvrmgr::Daemon::ActionStash;
 
 extends 'Siebel::Srvrmgr::Daemon::Action';
+our $VERSION = '0.24'; # VERSION
 
 =head1 METHODS
 
