@@ -1,10 +1,11 @@
 package Siebel::Srvrmgr::Daemon::Action::Serializable;
-$Siebel::Srvrmgr::Daemon::Action::Serializable::VERSION = '0.23';
-use Moose::Role 2.1604;
-use Storable 2.51 qw(nstore);
+
 use warnings;
 use strict;
+use Moose::Role 2.1604;
+use Storable 2.51 qw(nstore);
 use Carp;
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
@@ -21,8 +22,8 @@ needs serialization to the filesystem.
 
 =head2 dump_file
 
-This attribute is a string used to indicate in which file the data from L<Siebel::Srvmrgr::ListParser::Output::ListCompDef> should
-be serialized into the OS filesystem. The string can be a complete path or just the filename.
+This attribute is a string used to indicate in which file the data from the class using this role should be serialized into 
+the OS filesystem. The string can be a complete path or just the filename.
 
 =cut
 
@@ -95,8 +96,7 @@ Returns any value returned by the C<nstore> function.
 
 sub store {
 
-    my $self     = shift;
-    my $data_ref = shift;
+    my ($self, $data_ref) = @_;
 
     confess "the received parameter is not a reference"
       if ( ref($data_ref) eq '' );
