@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::ActionStash;
-$Siebel::Srvrmgr::Daemon::ActionStash::VERSION = '0.23';
+
 =pod
 
 =head1 NAME
@@ -41,7 +41,8 @@ Considering this situation, the interface of this class should be considered exp
 
 use warnings;
 use strict;
-use MooseX::Singleton;
+use MooseX::Singleton 0.29;
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
