@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::Heavy;
-$Siebel::Srvrmgr::Daemon::Heavy::VERSION = '0.23';
+
 =pod
 
 =head1 NAME
@@ -47,18 +47,16 @@ Siebel::Srvrmgr::Daemon::Heavy - "heavier" implementation of Siebel::Srvrmgr::Da
 
 =head1 DESCRIPTION
 
-This class extends L<Siebel::Srvmrgr::Daemon>. By "Heavy" understand more complex code to be able to deal with a large number of commands
+This class extends L<Siebel::Srvmrgr::Daemon>. By "Heavy" you should understand as more complex code to be able to deal with a large number of commands
 of C<srvrmgr>.
 
-This class is indicated to be used in cenarios where several commands need to be executed in a short time interval: it will connect to srvrmgr by using 
+This class is indicated to be used in scenarios where several commands need to be executed in a short time interval: it will connect to srvrmgr by using 
 IPC for communication between the processes and once connected, the srvrmgr session will be reused as many times as desired instead of following the
 sequence of connect -> run commands -> disconnect.
 
 The sessions are not "interactive" from the user point of view but the usage of this class enable the adoption of some logic to change how the commands will 
 be executed or even generate commands on the fly.
 
-This module is based on L<IPC::Open3::Callback> from Lucas Theisen (see SEE ALSO section) implemented in L<Siebel::Srvrmgr::Daemon::IPC>.
-
 Since it uses Perl IPC, this class may suffer from good support in OS plataforms that are not UNIX-like. Be sure to check out tests results of the distribution
 before trying to use it.
 
@@ -73,13 +71,14 @@ use Siebel::Srvrmgr::Regexes
 use Siebel::Srvrmgr::Daemon::Command;
 use POSIX;
 use Data::Dumper;
-use Scalar::Util qw(weaken openhandle);
+use Scalar::Util qw(openhandle);
 use Config;
 use Siebel::Srvrmgr::IPC;
 use IO::Select;
 use Encode;
 use Carp qw(longmess);
 use Siebel::Srvrmgr;
+our $VERSION = '0.24'; # VERSION
 
 extends 'Siebel::Srvrmgr::Daemon';
 
@@ -446,8 +445,14 @@ override 'run' => sub {
 # :WARNING:16-07-2014 11:35:13:: cannot using SRVRMGR_PROMPT regex because it is too restrictive
 # since we are reading a stream here. The regex is a copy of SRVRMGR_PROMPT without the "^" at the beginning
     my $prompt_regex = qr/srvrmgr(\:[\w\_\-]+)?>\s(.*)?$/;
-    my $eol_regex    = qr/\015\012$/;
-    my $buffer_size  = $self->get_buffer_size();
+
+# :WARNING:22-03-2016 23:21:53:: configuration of EOL is obscure but possible in Siebel. The hardcode values might
+# be a problem
+# :TODO:22-03-2016 23:22:29:: add more attributes to take care of it, with default values
+    my $CR = "\o{15}";
+    my $LF = "\o{12}";
+    my $eol_regex   = qr/$CR$LF$/;
+    my $buffer_size = $self->get_buffer_size();
 
     if ( $logger->is_debug() ) {
 
@@ -461,15 +466,15 @@ override 'run' => sub {
 
       SWITCH: {
 
-            if ( $/ eq \015 ) {
+            if ( $/ eq $CR ) {
                 $logger->debug( $assert . 'CR' );
                 last SWITCH;
             }
-            if ( $/ eq ( \015 . \012 ) ) {
+            if ( $/ eq ("$CR$LF") ) {
                 $logger->debug( $assert . 'CRLF' );
                 last SWITCH;
             }
-            if ( $/ eq \012 ) {
+            if ( $/ eq $LF ) {
                 $logger->debug( $assert . 'LF' );
                 last SWITCH;
             }
@@ -489,9 +494,7 @@ override 'run' => sub {
         while ( my @ready = $select->can_read($timeout) ) {
 
             foreach my $fh (@ready) {
-
                 my $fh_name = fileno($fh);
-
                 $logger->debug("Reading filehandle $fh_name")
                   if ( $logger->is_debug() );
 
@@ -505,7 +508,6 @@ override 'run' => sub {
 
                 }
                 else {
-
                     $logger->info(
                         'Caught part of a record, repeating sysread with offset'
                     ) if ( $logger->is_info() );
@@ -1120,23 +1122,13 @@ sub _my_cleanup {
 
 sub _submit_cmd {
 
-    my $self       = shift;
-    my $cmd        = shift;
-    my $logger     = shift;
-    my $has_logger = 0;
-
-    if ( ( defined($logger) ) and ( ref($logger) ) ) {
-
-        weaken($logger);
-        $has_logger = 1;
-
-    }
-
+    my ( $self, $cmd ) = @_;
+    my $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
     my $bytes = syswrite $self->get_write(), "$cmd\n";
 
     if ( defined($bytes) ) {
 
-        if ( $has_logger && $logger->is_debug() ) {
+        if ( $logger->is_debug() ) {
 
             $logger->debug("Submitted $cmd, wrote $bytes bytes");
 
@@ -1145,20 +1137,8 @@ sub _submit_cmd {
     }
     else {
 
-        if ($has_logger) {
-
-            $logger->logdie( 'A failure occurred when trying to submit '
-                  . $cmd . ': '
-                  . $! );
-
-        }
-        else {
-
-            die(    'A failure occurred when trying to submit '
-                  . $cmd . ': '
-                  . $! );
-
-        }
+        $logger->logdie(
+            'A failure occurred when trying to submit ' . $cmd . ': ' . $! );
 
     }
 
@@ -1178,9 +1158,7 @@ handles associated with the child will be closed. If after that the PID is still
 For MS Windows OS, this might not be sufficient: the PID will be checked again after C<waitpid>, and if it is still running, this method will try to use
 C<kill 9> to eliminate the process.
 
-If the child process is terminated succesfully, this method returns true. If there is no PID associated with the Daemon instance, this method will return false.
-
-Accepts as an optional parameter an instance of a L<Log::Log4perl> for logging messages.
+If the child process is terminated successfully, this method returns true. If there is no PID associated with the Daemon instance, this method will return false.
 
 =cut
 
@@ -1202,7 +1180,7 @@ sub close_child {
             and ( not($SIG_ALARM) ) )
         {
 
-            $self->_submit_cmd( 'exit', $logger );
+            $self->_submit_cmd('exit');
 
             if ( $logger->is_debug() ) {
 
@@ -1249,7 +1227,7 @@ sub close_child {
                 if ( $ret == $self->get_pid() ) {
 
 # :WORKAROUND:14/08/2013 17:44:00:: for Windows, not using shutdown when creating the socketpair causes the application to not
-# exit with waitpid. using waitpid without non-blocking mode just blocks the application to finish
+# exit with waitpid. Using waitpid without non-blocking mode just blocks the application to finish
                     if ( $Config{osname} eq 'MSWin32' ) {
 
                         if ( kill 0, $self->get_pid() ) {
@@ -1316,6 +1294,16 @@ sub close_child {
 
 =pod
 
+=head1 BACKGROUND EXECUTION
+
+If you're in a UNIX-like OS, you might want to execute some code with this class as a background process. This can be easily done with:
+
+    nohup ~/perl5/perlbrew/perls/perl-5.16.3/bin/perl ~/my_script.pl
+    CRTL+Z
+    bg 1
+
+In this example, the Perl interpreter was located in C<~/perl5/perlbrew/perls/perl-5.16.3/bin/perl> but of course you location might be different.
+
 =head1 CAVEATS
 
 This class is still considered experimental and should be used with care. Tests with MS Windows (and the nature of doing IPC within the plataform) makes it difficult do use this class in Microsoft OS's.
@@ -1332,7 +1320,7 @@ L<IPC::Open3>
 
 =item *
 
-L<Moose>
+L<Siebel::Srvrmgr:::Daemon>
 
 =item *
 
@@ -1356,16 +1344,8 @@ L<POSIX>
 
 =item *
 
-L<Siebel::Srvrmgr::Daemon::Command>
-
-=item *
-
 L<Siebel::Srvrmgr::Daemon::IPC>
 
-=item *
-
-L<https://github.com/lucastheisen/ipc-open3-callback>
-
 =back
 
 =head1 AUTHOR
