@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::Light;
-$Siebel::Srvrmgr::Daemon::Light::VERSION = '0.23';
+
 =pod
 
 =head1 NAME
@@ -73,6 +73,7 @@ use Data::Dumper;
 use Siebel::Srvrmgr;
 use File::BOM 0.14 qw(:all);
 use Siebel::Srvrmgr::IPC qw(check_system);
+our $VERSION = '0.24'; # VERSION
 
 extends 'Siebel::Srvrmgr::Daemon';
 
@@ -267,7 +268,7 @@ sub cmds_vs_tree {
     }
     else {
 
-        return undef;
+        return;
 
     }
 
