@@ -1,10 +1,11 @@
 package Siebel::Srvrmgr::ListParser::Output::Duration;
-$Siebel::Srvrmgr::ListParser::Output::Duration::VERSION = '0.23';
-use Moose::Role 2.1604;
-use Carp;
+
 use warnings;
 use strict;
-use DateTime;
+use Moose::Role 2.1604;
+use Carp;
+use DateTime 1.12;
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
