@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::ListParser::Output::ListComp::Server;
-$Siebel::Srvrmgr::ListParser::Output::ListComp::Server::VERSION = '0.23';
+
 =pod
 
 =head1 NAME
@@ -9,10 +9,11 @@ Siebel::Srvrmgr::ListParser::Output::ListComp::Server - class to parse and aggre
 =cut
 
 use Moose 2.0401;
-use MooseX::Storage 0.33;
 use namespace::autoclean 0.13;
 use Siebel::Srvrmgr::ListParser::Output::ListComp::Comp;
 use Carp;
+use Storable qw(nstore);
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
@@ -32,12 +33,8 @@ use Carp;
 This class represents a server in a Siebel Enterprise and it's related components. This class is meant to be instantied by a method from 
 L<Siebel::Srvrmgr::ListParser::Output::ListComp> object.
 
-This class inherits from L<MooseX::Storage>, using the L<MooseX::Storage::IO::StorableFile> trait. See the methods C<load> and C<store> for details.
-
 =cut
 
-with Storage( io => 'StorableFile' );
-
 =head1 ATTRIBUTES
 
 =head2 data
@@ -85,18 +82,21 @@ Returns an hash reference from the C<data> attribute.
 
 Returns an string from the C<name> attribute.
 
-=head2 load
-
-Load the object data and methods from a previously serialized object.
-
-Expects as a parameter a string the filename (or complete path).
-
 =head2 store
 
 Stores the object data and methods in a serialized file.
 
 Expects as a parameter a string the filename (or complete path).
 
+=cut
+
+sub store {
+
+    my ( $self, $filename ) = @_;
+    nstore $self, $filename;
+
+}
+
 =head2 get_comps
 
 Returns an array reference with all components aliases available in the server.
@@ -155,7 +155,7 @@ sub get_comp {
     }
     else {
 
-        return undef;
+        return;
 
     }
 
@@ -173,10 +173,6 @@ L<Moose>
 
 =item *
 
-L<MooseX::Storage>
-
-=item *
-
 L<namespace::autoclean>
 
 =item *
