@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::ListParser::Output::LoadPreferences;
-$Siebel::Srvrmgr::ListParser::Output::LoadPreferences::VERSION = '0.23';
+
 =pod
 
 =head1 NAME
@@ -14,6 +14,7 @@ use namespace::autoclean 0.13;
 use Carp;
 
 extends 'Siebel::Srvrmgr::ListParser::Output';
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
@@ -64,9 +65,7 @@ The C<raw_data> attribute will be set to an reference to an empty array.
 override 'parse' => sub {
 
     my $self = shift;
-
     my $data_ref = $self->get_raw_data();
-
     my %parsed_lines;
 
     foreach my $line ( @{$data_ref} ) {
@@ -99,7 +98,7 @@ override 'parse' => sub {
             }
             else {
 
-                confess 'Invalid data in line [' . $line . ']';
+                confess "Invalid data in line [$line]";
 
             }
 
