@@ -1,9 +1,10 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::ByServer;
-$Siebel::Srvrmgr::ListParser::Output::Tabular::ByServer::VERSION = '0.23';
+
 use strict;
 use warnings;
 use Moose::Role 2.1604;
 use Siebel::Srvrmgr::Regexes qw(SIEBEL_SERVER);
+our $VERSION = '0.24'; # VERSION
 
 =head1 NAME
 
@@ -46,8 +47,8 @@ Returns a list of the Siebel Server names from the parsed output, sorted alphabe
 sub get_servers {
 
     my $self = shift;
-
-    return sort( keys( %{ $self->get_data_parsed() } ) );
+    my @servers = sort( keys( %{ $self->get_data_parsed() } ) );
+    return @servers;
 
 }
 
