@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::ListComp;
-$Siebel::Srvrmgr::ListParser::Output::Tabular::ListComp::VERSION = '0.23';
+
 =pod
 
 =head1 NAME
@@ -12,6 +12,7 @@ use Moose 2.0401;
 use namespace::autoclean 0.13;
 use Siebel::Srvrmgr::ListParser::Output::ListComp::Server;
 use Siebel::Srvrmgr::ListParser::Output::ListComp::Comp;
+our $VERSION = '0.24'; # VERSION
 
 =head1 SYNOPSIS
 
@@ -223,7 +224,7 @@ sub get_server {
     }
     else {
 
-        return undef;
+        return;
 
     }
 
