@@ -1,8 +1,9 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::ListProcs;
-$Siebel::Srvrmgr::ListParser::Output::Tabular::ListProcs::VERSION = '0.23';
+
 use Moose 2.0401;
 use namespace::autoclean 0.13;
 use Siebel::Srvrmgr::ListParser::Output::ListProcs::Proc;
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
@@ -115,7 +116,7 @@ sub get_procs {
         }
         else {
 
-            return undef;
+            return;
 
         }
 
