@@ -1,8 +1,9 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::ListServers;
-$Siebel::Srvrmgr::ListParser::Output::Tabular::ListServers::VERSION = '0.23';
+
 use Moose 2.0401;
 use namespace::autoclean 0.13;
 use Siebel::Srvrmgr::ListParser::Output::ListServers::Server;
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
@@ -134,7 +135,7 @@ sub get_servers {
         }
         else {
 
-            return undef;
+            return;
 
         }
 
