@@ -1,9 +1,10 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::ListSessions;
-$Siebel::Srvrmgr::ListParser::Output::Tabular::ListSessions::VERSION = '0.23';
+
 use Moose 2.0401;
 use namespace::autoclean 0.13;
 use Carp qw(cluck);
 use Siebel::Srvrmgr::Regexes qw(SIEBEL_SERVER);
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
@@ -311,7 +312,7 @@ sub get_sessions {
         }
         else {
 
-            return undef;
+            return;
 
         }
 
