@@ -1,9 +1,10 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::ListTasks;
-$Siebel::Srvrmgr::ListParser::Output::Tabular::ListTasks::VERSION = '0.23';
+
 use Moose 2.0401;
 use Siebel::Srvrmgr::ListParser::Output::ListTasks::Task;
 use namespace::autoclean 0.13;
 use Siebel::Srvrmgr::Regexes qw(SIEBEL_SERVER);
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
@@ -221,7 +222,7 @@ sub get_tasks {
         }
         else {
 
-            return undef;
+            return;
 
         }
 
