@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::Struct;
-$Siebel::Srvrmgr::ListParser::Output::Tabular::Struct::VERSION = '0.23';
+
 =pod
 
 =head1 NAME
@@ -11,6 +11,7 @@ Siebel::Srvrmgr::ListParser::Output::Tabular::Struct - base class for parsing sr
 use Moose 2.0401;
 use namespace::autoclean 0.13;
 use Carp;
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
@@ -126,11 +127,8 @@ If the separator could not be matched against the string, returns C<undef>.
 
 sub split_fields {
 
-    my $self = shift;
-    my $line = shift;
-
+    my ($self, $line) = @_;
     my $sep = $self->get_col_sep();
-
     my $comp_sep = qr/$sep/;
 
     if ( $line =~ $comp_sep ) {
@@ -141,7 +139,7 @@ sub split_fields {
     }
     else {
 
-        return undef;
+        return;
 
     }
 
