@@ -1,12 +1,13 @@
 package Siebel::Srvrmgr::Log::Enterprise::Parser::Comp_alias;
-$Siebel::Srvrmgr::Log::Enterprise::Parser::Comp_alias::VERSION = '0.23';
+
 use Moose;
 use namespace::autoclean;
-use Set::Tiny;
+use Set::Tiny 0.02;
 use Carp qw(cluck confess);
 use Siebel::Srvrmgr::Log::Enterprise;
 
 with 'Siebel::Srvrmgr::Comps_source';
+our $VERSION = '0.24'; # VERSION
 
 =pod
 
